@@ -63,17 +63,19 @@ class ButterStore(Store.Store):
 
         """
         # Don't lose a trailing slash -- it's significant
-        path = os.path.abspath(path) + "/" if path.endswith("/") else ""
+        path = os.path.abspath(path) + ("/" if path.endswith("/") else "")
 
         super(ButterStore, self).__init__(path, isDest)
 
+        if not os.path.isdir(self.userPath):
+            raise Exception("'%s' is not an existing directory" % (self.userPath))
+
         self.isDest = isDest
 
-        self.butter = Butter.Butter(self.userPath)  # subprocess command-line interface
+        self.butter = Butter.Butter()  # subprocess command-line interface
         self.btrfs = btrfs.FileSystem(self.userPath)     # ioctl interface
 
         self.butterVolumes = {}   # Dict of {uuid: <btrfs.Volume>}
-        # self.volumes = self.butter.listVolumes()
         self._fillVolumesAndPaths()
 
     def _btrfsVol2StoreVol(self, bvol):
@@ -107,7 +109,7 @@ class ButterStore(Store.Store):
                         continue
 
                     logger.debug("%s %s", vol, path)
-                    self.paths[vol].add(path)
+                    self.paths[vol].append(path)
 
                 if vol not in self.paths:
                     continue
@@ -120,6 +122,10 @@ class ButterStore(Store.Store):
 
                 self.butterVolumes[vol.uuid] = bv
 
+    def _fileSystemSync(self):
+        with self.btrfs as mount:
+            mount.SYNC()
+
     def __unicode__(self):
         """ English description of self. """
         return u"btrfs %s" % (self.userPath)
@@ -167,6 +173,9 @@ class ButterStore(Store.Store):
 
     def receive(self, diff, paths, dryrun=False):
         """ Return Context Manager for a file-like (stream) object to store a diff. """
+        if not dryrun:
+            self._fileSystemSync()
+
         path = self.selectReceivePath(paths)
 
         stream = self.butter.receive(os.path.dirname(path), dryrun)
@@ -225,4 +234,13 @@ class ButterStore(Store.Store):
 
     def send(self, diff, streamContext, progress=True, dryrun=False):
         """ Write the diff (toVol from fromVol) to the stream context manager. """
-        self.butter.send(diff.toUUID, diff.fromUUID, streamContext, progress, dryrun)
+        if not dryrun:
+            self._fileSystemSync()
+
+        self.butter.send(
+            self.getSendPath(diff.toVol),
+            self.getSendPath(diff.fromVol),
+            streamContext,
+            progress,
+            dryrun
+        )
