@@ -29,6 +29,9 @@ if True:  # Imports and constants
         # This does transparent S3 server-side encryption
         isEncrypted = True
 
+        # Minimum chuck size is 5M.
+        theInfoBufferSize = 10 * (1 << 20)
+
         logger = logging.getLogger(__name__)
 
 # logger.setLevel('DEBUG')
@@ -106,7 +109,7 @@ class S3Store(Store.Store):
             logger.debug("Adding %s in %s", diff, path)
 
             self.diffs[diff.fromVol].append(diff)
-            self.paths[diff.toVol].add(path)
+            self.paths[diff.toVol].append(path)
 
         # logger.debug("Diffs:\n%s", pprint.pformat(self.diffs))
         # logger.debug("Vols:\n%s", pprint.pformat(self.vols))
@@ -137,7 +140,7 @@ class S3Store(Store.Store):
         if Store.skipDryRun(logger, dryrun)("receive info in '%s'", path):
             return None
 
-        return _Uploader(self.bucket, path)
+        return io.BufferedWriter(_Uploader(self.bucket, path), buffer_size=theInfoBufferSize)
 
     theKeyPattern = "^(?P<fullpath>.*)/(?P<to>[-a-zA-Z0-9]*)_(?P<from>[-a-zA-Z0-9]*)$"
 
@@ -176,21 +179,6 @@ class S3Store(Store.Store):
         if progress:
             sys.stdout.write("\n")
 
-    def _upload(self, stream, keyName):
-        # key = self.bucket.get_key(keyName)
-        # key = self.bucket.new_key(keyName)
-
-        # set_contents_from_stream is not supported for S3
-        # key.set_contents_from_stream(stream, replace=False, cb=displayProgress, size=1000)
-        # key.set_contents_from_filename(fileName, replace=False, cb=displayProgress)
-
-        with _Uploader(self.bucket, keyName) as uploader:
-            while True:
-                data = stream.read(theChunkSize)
-                if not data:
-                    break
-                uploader.upload(data)
-
 
 class _DisplayProgress:
 
