@@ -29,14 +29,20 @@ class Store(object):
     def __init__(self, userPath, isDest):
         """ Initialize. """
         # { vol: [path] }
-        self.paths = collections.defaultdict((lambda: set()))
+        # The order of the paths is important to work around btrfs bugs.
+        # The first path is usually the root-volume mounted path,
+        # which is required by btrfs 3.14.2.
+        self.paths = collections.defaultdict((lambda: []))
 
         # Paths specify a directory containing subvolumes,
         # unless it's a source path not ending in "/",
         # then it's a single source subvolume.
 
         if not (userPath.endswith("/") or isDest):
+            self.userVolume = os.path.basename(userPath)
             userPath = os.path.dirname(userPath)
+        else:
+            self.userVolume = None
 
         # This will not end with a "/"
         userPath = os.path.normpath(userPath)
@@ -50,8 +56,11 @@ class Store(object):
         """ Return list of all volumes in this Store's selected directory. """
         for (vol, paths) in self.paths.items():
             for path in paths:
-                if not path.startswith('/'):
-                    yield vol
+                if path.startswith('/'):
+                    continue
+                if self.userVolume is not None and os.path.basename(path) != self.userVolume:
+                    continue
+                yield vol
                 break
 
     def getPaths(self, volume):
@@ -73,14 +82,14 @@ class Store(object):
         """ From a set of destination paths, select the best one to receive to.
 
         The paths are relative or absolute, in a source Store.
-        The result will be relative, suitable for this destination Store.
+        The result will be absolute, suitable for this destination Store.
 
         """
         logger.debug("%s", paths)
         try:
             return self._fullPath([p for p in paths if not p.startswith("/")][0])
         except IndexError:
-            return os.path.basename(list(paths)[0])
+            return self._fullPath(os.path.basename(list(paths)[0]))
 
     def _fullPath(self, path):
         if path.startswith("/"):
@@ -188,8 +197,8 @@ class Diff:
         return u"%s from %s (%s%s) in %s" % (
             self.toVol.display(self.sink),
             self.fromVol.display(self.sink) if self.fromVol else "<None>",
+            "~" if self.sizeIsEstimated else "",
             humanize(self.size),
-            "-e" if self.sizeIsEstimated else "",
             self.sink,
         )
 
@@ -279,23 +288,6 @@ class Volume:
 
         return vol + size
 
-    @staticmethod
-    def getPath(node):
-        """ Return printable description of node, if not None. """
-        if node is None:
-            return None
-        uuid = node.uuid
-        return node._getPath(uuid)
-
-    def _getPath(self, uuid):
-        """ Return printable description of uuid. """
-        result = Store.printUUID(uuid)
-        try:
-            result = "%s (%s)" % (self.diffSink.getVolume(uuid)['path'], result)
-        except (KeyError, AttributeError):
-            pass
-        return result
-
     @classmethod
     def make(cls, vol):
         """ Convert uuid to Volume, if necessary. """
