@@ -11,6 +11,7 @@ if True:  # Headers
 
         import argparse
         import logging
+        import os.path
         import re
         import sys
 
@@ -24,7 +25,7 @@ theDebug = False
 logger = logging.getLogger(__name__)
 # logger.setLevel('DEBUG')
 
-theVersionFile = "version.txt"
+theVersionFile = os.path.join(os.path.dirname(__file__), "version.txt")
 try:
     with open(theVersionFile) as version:
         theVersion = version.readline()
@@ -35,11 +36,12 @@ except IOError:
 command = argparse.ArgumentParser(
     description="Synchronize two sets of btrfs snapshots.",
     epilog="""
-<src>, <dst>:   file:///path/to/directory/[snapshot]
+<src>, <dst>:   [file://]/path/to/directory/[snapshot]
                 ssh://[user@]host/path/to/directory (Not implemented)
                 s3://bucket/prefix/[snapshot]
 
-If only <dst> is supplied, just list available snapshots.
+If only <dst> is supplied, just list available snapshots.  The trailing "/"
+on a <src> *is* significant.
 
 Copyright (c) 2014 Ames Cornish.  All rights reserved.  Licensed under GPLv3.
 See README.md and LICENSE.txt for more info.
@@ -56,7 +58,7 @@ command.add_argument('-n', '--dry-run', action="store_true",
                      help="display what would be transferred, but don't do it",
                      )
 command.add_argument('-d', '--delete', action="store_true",
-                     help='delete any snapshots in <dst> that are not in <src>',
+                     help='delete any snapshots in <dst> that are not in <src> (Not implemented)',
                      )
 
 command.add_argument('-q', '--quiet', action="count", default=0,
@@ -87,11 +89,11 @@ def _setupLogging(quietLevel, logFile):
     theDebugDisplayFormat = (
         '%(levelname)7s:'
         '%(filename)s[%(lineno)d] %(funcName)s(): %(message)s'
-        )
+    )
     theLogFormat = (
         '%(asctime)-15s: %(levelname)7s:'
         '%(filename)s[%(lineno)d] %(funcName)s(): %(message)s'
-        )
+    )
 
     root = logging.getLogger()
     root.setLevel("INFO" if theDebug else "DEBUG")  # When debugging, this is handled per-logger
@@ -165,10 +167,13 @@ def main():
     best.analyze(source, dest)
 
     summary = best.summary()
-    logger.info("Optimal synchronization: %d diffs, %s total",
-                summary["count"], Store.humanize(summary["size"]))
-    for sink, size in summary["sinks"].items():
-        logger.info("%s from %s", Store.humanize(size), sink)
+    logger.info("Optimal synchronization:")
+    for sink, values in summary.items():
+        logger.info("%s from %d diffs in %s",
+                    Store.humanize(values.size),
+                    values.count,
+                    sink or "TOTAL",
+                    )
 
     for diff in best.iterDiffs():
         if diff is None:
@@ -185,25 +190,18 @@ def main():
 
             diff.sink.send(diff, streamContext, progress=progress, dryrun=args.dry_run)
 
-        # TODO: For symmetry, put this into the streamContext.__exit__ method
+            # TODO: For symmetry, put this into the streamContext.__exit__ method
 
-        if vol.hasInfo():
-            infoContext = dest.receiveVolumeInfo(paths, dryrun=args.dry_run)
+            if vol.hasInfo():
+                infoContext = dest.receiveVolumeInfo(paths, dryrun=args.dry_run)
 
-            if args.dry_run:
-                vol.writeInfo(sys.stdout)
-            else:
-                with infoContext as stream:
-                    vol.writeInfo(stream)
+                if args.dry_run:
+                    vol.writeInfo(sys.stdout)
+                else:
+                    with infoContext as stream:
+                        vol.writeInfo(stream)
 
     return 0
 
 if __name__ == "__main__":
-    try:
-        sys.exit(main())
-    except Exception as err:
-        if theDebug:
-            logger.exception("")
-
-        sys.stderr.write("*** ERROR: %s\n" % (err))
-        sys.exit(-1)
+    sys.exit(main())
